==> kpogre-1.2.7.tar.gz: kpogre-1.2.7/kpogre/DbObjects/kpgrulesfolder.cpp <==
//
// C++ Implementation: kpgrulesfolder
//
// Description: 
//
//
// Author: Lumir Vanek <lvanek@users.sourceforge.net>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//
#include "kpgrulesfolder.h"

// include files for KDE
#include <kdebug.h>
#include <kmessagebox.h>
#include <klocale.h>

#include <qtable.h>

#include "kpgconnection.h"
#include "../PropertyPages/kpgpropertypage.h"
#include "kpgrule.h"
#include "../kpgsqldialog.h"

KPGRulesFolder::KPGRulesFolder(KPGTable *parent)
 : KPGTableItemsFolder(parent, i18n("Rules"))
{
	setPixmap(0, *m_pIconFolderYellow);
}

KPGRulesFolder::KPGRulesFolder(KPGTable *parent, KPGTableItemsFolder *after)
 : KPGTableItemsFolder(parent, after, i18n("Rules"))
{
	setPixmap(0, *m_pIconFolderYellow);
}

KPGRulesFolder::~KPGRulesFolder()
{
}

bool KPGRulesFolder::refresh(work &pqxxXaction, pqxx::oid oidTable)
{
  // delete all child items (databases)
  while (QListViewItem * pItem = firstChild())
    delete pItem;

  QString strQuery("SELECT rw.oid, rulename, description, is_instead, ev_type, ev_qual, nspname ");
	strQuery.append("FROM pg_rewrite rw ");
	strQuery.append("JOIN pg_class cl ON cl.oid=rw.ev_class ");
	strQuery.append("JOIN pg_namespace nsp ON nsp.oid=cl.relnamespace ");
  strQuery.append("LEFT OUTER JOIN pg_description des ON des.objoid=rw.oid ");
  strQuery.append("WHERE ev_class = ");
	strQuery.append(QString("%1").arg(oidTable));
  strQuery.append(" ORDER BY rulename");
		
  try
  {
	  m_pqxxResultRules = pqxxXaction.exec(strQuery.latin1());
		
		KPGRule *pgRule = 0;
		
		for (result::size_type i = 0; i != m_pqxxResultRules.size(); ++i)
    {
		  pqxx::oid oid;
			m_pqxxResultRules[i][0].to(oid);
			
			if(pgRule == 0)
				pgRule = new KPGRule(this, m_pqxxResultRules[i]["rulename"].c_str(), oid);
			else
				pgRule = new KPGRule(this, pgRule, m_pqxxResultRules[i]["rulename"].c_str(), oid);
			
			bool bIsInstead;
			
			m_pqxxResultRules[i]["is_instead"].to(bIsInstead);
			
			pgRule->setProperties(
				m_pqxxResultRules[i]["description"].c_str(),
				bIsInstead,
				m_pqxxResultRules[i]["ev_type"].c_str(),
				m_pqxxResultRules[i]["ev_qual"].c_str(),
				m_pqxxResultRules[i]["nspname"].c_str()
				);
				
			//-- Get definition
			strQuery = QString("SELECT pg_get_ruledef(%1) AS definition;").arg(oid);
			pqxx::result pqxxResultDefinition = pqxxXaction.exec(strQuery.latin1());
		
			if (pqxxResultDefinition.size() > 0)
    	{ 
				pgRule->setDefinition(pqxxResultDefinition[0][0].c_str());
			}
		}
	}
  catch (const std::exception &e)
  {
    kdError() << e.what() << endl;
    KPGSqlDialog dlg(0, strQuery, e.what());
		dlg.exec();
    return false;
  } 
  
  return true;
}

void KPGRulesFolder::displayProperties(QWidget *widgetProperies)
{
	KPGPropertyPage *pPropertyPage = static_cast <KPGPropertyPage *> (widgetProperies);
  pPropertyPage->setLabelText(i18n("Rules &list:"));
	
	//----------------------------------------------------------------------------
	//Display rules list
	QTable *pTableRules = pPropertyPage->m_pTableItems;
		
	// fill properties table with result data
	int nTableCols = fillPropertiesTable(m_pqxxResultRules, pTableRules);

	// field names
  QHeader* hHeader = pTableRules->horizontalHeader();

	int nCol = 0;
	hHeader->setLabel(nCol++, i18n("Name"));
	hHeader->setLabel(nCol++, i18n("Description"));
	hHeader->setLabel(nCol++, i18n("Is instead"));
	hHeader->setLabel(nCol++, i18n("Event type"));
  hHeader->setLabel(nCol++, i18n("Qualifying condition"));
  hHeader->setLabel(nCol++, i18n("Namespace"));
	
  for(int nCol = 0; nCol < nTableCols; nCol++)
  {
    pTableRules->adjustColumn(nCol);
  }
}

==> kpogre-1.5.2.tar.gz: kpogre-1.5.2/kpogre/DbObjects/kpgrulesfolder.cpp <==
//
// C++ Implementation: kpgrulesfolder
//
// Description: 
//
//
// Author: Lumir Vanek <lvanek@users.sourceforge.net>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//
#include "kpgrulesfolder.h"

// include files for KDE
#include <kdebug.h>
#include <kmessagebox.h>
#include <klocale.h>

#include <qtable.h>

#include "kpgconnection.h"
#include "../PropertyPages/kpgpropertypage.h"
#include "kpgrule.h"
#include "../kpgsqldialog.h"

KPGRulesFolder::KPGRulesFolder(KPGTable *parent)
 : KPGTableItemsFolder(parent, i18n("Rules"))
{
	setPixmap(0, *m_pIconFolderYellow);
}

KPGRulesFolder::KPGRulesFolder(KPGTable *parent, KPGTableItemsFolder *after)
 : KPGTableItemsFolder(parent, after, i18n("Rules"))
{
	setPixmap(0, *m_pIconFolderYellow);
}

KPGRulesFolder::~KPGRulesFolder()
{
}

bool KPGRulesFolder::refresh(work &pqxxXaction, pqxx::oid oidTable)
{
	// delete all child items (databases)
	while (QListViewItem * pItem = firstChild())
		delete pItem;
	
	QString strQuery("SELECT rw.oid, rulename, description, is_instead, ev_type, ev_qual, nspname ");
	strQuery.append("FROM pg_catalog.pg_rewrite rw ");
	strQuery.append("JOIN pg_catalog.pg_class cl ON cl.oid=rw.ev_class ");
	strQuery.append("JOIN pg_catalog.pg_namespace nsp ON nsp.oid=cl.relnamespace ");
	strQuery.append("LEFT OUTER JOIN pg_catalog.pg_description des ON des.objoid=rw.oid ");
	strQuery.append("WHERE ev_class = ");
	strQuery.append(QString("%1").arg(oidTable));
	strQuery.append(" ORDER BY rulename");
			
	try
	{
		m_pqxxResultRules = pqxxXaction.exec(strQuery.latin1());
			
		KPGRule *pgRule = 0;
			
		for (result::size_type i = 0; i != m_pqxxResultRules.size(); ++i)
		{
			pqxx::oid oid;
			m_pqxxResultRules[i][0].to(oid);
				
			if(pgRule == 0)
				pgRule = new KPGRule(this, m_pqxxResultRules[i]["rulename"].c_str(), oid);
			else
				pgRule = new KPGRule(this, pgRule, m_pqxxResultRules[i]["rulename"].c_str(), oid);
				
			bool bIsInstead;
				
			m_pqxxResultRules[i]["is_instead"].to(bIsInstead);
				
			pgRule->setProperties(
				m_pqxxResultRules[i]["description"].c_str(),
				bIsInstead,
				m_pqxxResultRules[i]["ev_type"].c_str(),
				m_pqxxResultRules[i]["ev_qual"].c_str(),
				m_pqxxResultRules[i]["nspname"].c_str()
				);
					
			//-- Get definition
			strQuery = QString("SELECT pg_get_ruledef(%1) AS definition;").arg(oid);
			pqxx::result pqxxResultDefinition = pqxxXaction.exec(strQuery.latin1());
			
			if (pqxxResultDefinition.size() > 0)
			{ 
				pgRule->setDefinition(pqxxResultDefinition[0][0].c_str());
			}
		}
	}
	catch (const std::exception &e)
	{
		kdError() << e.what() << endl;
		KPGSqlDialog dlg(0, strQuery, e.what());
			dlg.exec();
		return false;
	} 
	
	return true;
}

void KPGRulesFolder::displayProperties(QWidget *widgetProperies)
{
	if(widgetProperies == 0) return; // be defensive, user may close Properties window
	
	KPGPropertyPage *pPropertyPage = static_cast <KPGPropertyPage *> (widgetProperies);
  	pPropertyPage->setLabelText(i18n("Rules &list:"));
	
	//----------------------------------------------------------------------------
	//Display rules list
	QTable *pTableRules = pPropertyPage->m_pTableItems;
		
	// fill properties table with result data
	int nTableCols = fillPropertiesTable(m_pqxxResultRules, pTableRules);

	// field names
  	QHeader* hHeader = pTableRules->horizontalHeader();

	int nCol = 0;
	hHeader->setLabel(nCol++, i18n("Name"));
	hHeader->setLabel(nCol++, i18n("Description"));
	hHeader->setLabel(nCol++, i18n("Is instead"));
	hHeader->setLabel(nCol++, i18n("Event type"));
	hHeader->setLabel(nCol++, i18n("Qualifying condition"));
	hHeader->setLabel(nCol++, i18n("Namespace"));
	
	for(int nCol = 0; nCol < nTableCols; nCol++)
	{
		pTableRules->adjustColumn(nCol);
	}
}
